==> opengtl_0.9.12.orig.tar.bz2: OpenGTL-0.9.12/OpenShiva/OpenShiva/wrappers/ImageWrap_p.cpp <==
/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ImageWrap_p.h"

#include "GTLCore/AbstractImage.h"
#include <GTLCore/PixelDescription.h>

#include "../Debug.h"

extern "C" {

char* image_wrap_data( ImageWrap* _imageWrap, int _x, int _y )
{
//   SHIVA_DEBUG( _imageWrap << " " << _x << " " << _y );
  SHIVA_ASSERT( _imageWrap );
  SHIVA_ASSERT( _imageWrap->image );
  return _imageWrap->image->data(_x, _y);
}

const char* image_wrap_const_data( const ImageWrap* _imageWrap, int _x, int _y )
{
  SHIVA_ASSERT( _imageWrap );
  SHIVA_ASSERT( _imageWrap->image );
  return ((const GTLCore::AbstractImage*)_imageWrap->image)->data(_x, _y);
}

int image_alpha_pos( ImageWrap* _imageWrap )
{
  SHIVA_ASSERT( _imageWrap );
  SHIVA_ASSERT( _imageWrap->image );
  return _imageWrap->image->pixelDescription().alphaPos();
}

}

==> opengtl_0.9.18.orig.tar.bz2: OpenGTL-0.9.18/OpenShiva/OpenShiva/wrappers/ImageWrap_p.cpp <==
/*
 *  Copyright (c) 2008 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "ImageWrap_p.h"

#include "GTLCore/AbstractImage.h"
#include <GTLCore/PixelDescription.h>

#include "../Debug.h"

extern "C" {

char* image_wrap_data( ImageWrap* _imageWrap, int _x, int _y )
{
//   SHIVA_DEBUG( _imageWrap << " " << _x << " " << _y );
  SHIVA_ASSERT( _imageWrap );
  SHIVA_ASSERT( _imageWrap->image );
  return _imageWrap->image->rawData(_x, _y);
}

const char* image_wrap_const_data( const ImageWrap* _imageWrap, int _x, int _y )
{
  SHIVA_ASSERT( _imageWrap );
  SHIVA_ASSERT( _imageWrap->image );
  return ((const GTLCore::AbstractImage*)_imageWrap->image)->rawData(_x, _y);
}

int image_alpha_pos( ImageWrap* _imageWrap )
{
  SHIVA_ASSERT( _imageWrap );
  SHIVA_ASSERT( _imageWrap->image );
  return _imageWrap->image->pixelDescription().alphaPos();
}

const GTLCore::AbstractColorConverter* image_color_converter( ImageWrap* _imageWrap )
{
  SHIVA_ASSERT( _imageWrap );
  SHIVA_ASSERT( _imageWrap->image );
  return _imageWrap->image->colorConverter();
}

}
